
# Tagger

[![GitHub](https://img.shields.io/github/license/mashape/apistatus.svg)](LICENSE)
[![pypi](https://img.shields.io/pypi/v/torch-tagger.svg)](https://pypi.python.org/pypi/torch-tagger)
[![travis-ci](https://travis-ci.org/infinity-future/torch-tagger.svg?branch=master)](https://travis-ci.org/infinity-future/torch-tagger/)

Tagger could use as named entity recognized(NER), part of speech tagging(POS), word segmentation

This repo use torch and RNN-CRF to do tag job

## Test

```sh
python3 -m tests
```